#global fz_rc beta2
%global run_autoconf 0

Name: filezilla
Version: 3.12.0.2
Release: 4%{?dist}
Summary: FTP, FTPS and SFTP client
Group: Applications/Internet
License: GPLv2+
URL: http://filezilla-project.org/
Source0: http://download.filezilla-project.org/FileZilla_%{version}%{?fz_rc:-%{?fz_rc}}_src.tar.bz2

Patch000: 6826.patch
Patch001: 6827.patch
Patch002: 6852.patch
Patch003: 7613.patch

%if 0%{?run_autoconf}
BuildRequires: automake
BuildRequires: autoconf
BuildRequires: libtool
%endif
BuildRequires: desktop-file-utils
BuildRequires: xdg-utils
BuildRequires: dbus-devel
BuildRequires: gettext
%if 0%{?fedora} || 0%{?rhel} > 6
BuildRequires: gnutls-devel >= 3.3.8
%else
BuildRequires: gnutls-devel >= 2.8.5
%endif
BuildRequires: libidn-devel
BuildRequires: sqlite-devel
BuildRequires: wxGTK3-devel >= 3.0.1
%if 0%{?fedora} || 0%{?rhel} > 6
BuildRequires: libappstream-glib
%endif

Requires: xdg-utils
Provides: bundled(tinyxml) = 2.6.2

%description
FileZilla is a FTP, FTPS and SFTP client for Linux with a lot of features.
- Supports FTP, FTP over SSL/TLS (FTPS) and SSH File Transfer Protocol (SFTP)
- Cross-platform
- Available in many languages
- Supports resume and transfer of large files >4GB
- Easy to use Site Manager and transfer queue
- Drag & drop support
- Speed limits
- Filename filters
- Network configuration wizard

%prep
%setup -q -n %{name}-%{version}%{?fz_rc:-%{?fz_rc}}

%patch000 -p0
%patch001 -p0
%patch002 -p0
%patch003 -p0

%if 0%{?run_autoconf}
%if 0%{?rhel} < 8
autoreconf -ivf
%endif
autoconf
%endif

%build
# For wxGTK3 - needed to find wxrc.
export WXRC=%{_bindir}/wxrc-3.0
%configure \
  --disable-static \
  --enable-locales \
  --disable-manualupdatecheck \
  --with-tinyxml=builtin \
  --with-wx-config=wx-config-3.0 \
%if 0%{?fedora} || 0%{?rhel} > 6
  --enable-gnutlssystemciphers \
%endif
  --disable-autoupdatecheck

make %{?_smp_mflags}

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p -c"

# Update the screenshot shown in the software center
#
# NOTE: It would be *awesome* if this file was pushed upstream.
#
# See http://people.freedesktop.org/~hughsient/appdata/#screenshots for more details.
#
appstream-util replace-screenshots $RPM_BUILD_ROOT%{_datadir}/appdata/filezilla.appdata.xml \
  https://raw.githubusercontent.com/hughsie/fedora-appstream/master/screenshots-extra/filezilla/a.png

for i in 16x16 32x32 48x48 ; do
  mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${i}/apps
  ln -sf ../../../../%{name}/resources/${i}/%{name}.png \
    $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

rm -rf $RPM_BUILD_ROOT%{_datadir}/pixmaps

desktop-file-install \
  --delete-original \
  --dir ${RPM_BUILD_ROOT}%{_datadir}/applications \
  ${RPM_BUILD_ROOT}%{_datadir}/applications/%{name}.desktop

appstream-util validate-relax --nonet \
  $RPM_BUILD_ROOT/%{_datadir}/appdata/*.appdata.xml

# Create directory for system wide settings
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
# Ghost configuration file
touch $RPM_BUILD_ROOT%{_sysconfdir}/%{name}/fzdefaults.xml
# This is not the usual docdir
rm -rf $RPM_BUILD_ROOT%{_datadir}/%{name}/docs

%find_lang %{name}

%check
make check

%post
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi || :

%postun
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi || :

%files -f %{name}.lang
%doc AUTHORS ChangeLog COPYING NEWS
%doc docs/fzdefaults.xml.example
%dir %{_sysconfdir}/%{name}
%ghost %{_sysconfdir}/%{name}/fzdefaults.xml
%{_bindir}/*
%{_datadir}/filezilla/
%{_datadir}/appdata/filezilla.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/filezilla.svg
%{_mandir}/man1/*
%{_mandir}/man5/*

%changelog
* Sat Nov 12 2016 Phil Wyett <philwyett.hemisphere@gmail.com> - 3.12.0.2-4
- Spec file cleanup.
- Patch SVN r6826. Remove assert that triggers on first entry into site manager.
- Patch SVN r6827. Socket object lives longer than TLS layer.
- Patch SVN r6852. Password prompt connecting on command line. Closes upstream #10605.

* Fri Nov 11 2016 Phil Wyett <philwyett.hemisphere@gmail.com> - 3.12.0.2-3
- Change to patch naming by upstream commit number where possible.

* Fri Jul 08 2016 Jon Ciesla <limburgher@gmail.com> - 3.12.0.2-2
- Patch for gtk bug.

* Wed Jul 22 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.12.0.2-1
- Update to 3.12.0.2

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.11.0.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed Jun 03 2015 Jon Ciesla <limburgher@gmail.com> - 3.11.0.2-1
- Update to 3.11.0.2.

* Tue May 26 2015 Jon Ciesla <limburgher@gmail.com> - 3.11.0.1-1
- Update to 3.11.0.1.

* Sat May 02 2015 Kalev Lember <kalevlember@gmail.com> - 3.10.3-2
- Rebuilt for GCC 5 C++11 ABI change

* Thu Apr 02 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.3-1
- Update to 3.10.3

* Mon Mar 30 2015 Richard Hughes <rhughes@redhat.com> - 3.10.3-0.3
- Use better AppData screenshots

* Tue Mar 17 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.3-0.2
- Update to 3.10.3-beta2

* Thu Mar 12 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.2-1
- Update to 3.10.2

* Wed Feb 25 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.2-0.1
- Update to 3.10.2-rc2

* Mon Jan 19 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.0.2-1
- Update to 3.10.0.2

* Wed Jan 07 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.0-1
- Update to 3.10.0
- Add appdata support for fedora

* Sun Jan 04 2015 Nicolas Chauvet <kwizart@gmail.com> - 3.10.0-0.1_rc2
- Update to 3.10.0-rc2

* Wed Nov 12 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0.6-2
- Rebuilt with fixed wxGTK3 - rhbz#1124402

* Mon Oct 20 2014 kwizart <kwizart@gmail.com> - 3.9.0.6-1
- Update to 3.9.0.6

* Fri Oct 03 2014 kwizart <kwizart@gmail.com> - 3.9.0.5-1
- Update to 3.9.0.5

* Fri Aug 29 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0.3-1
- Update to 3.9.0.3

* Sat Aug 16 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.9.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Jul 29 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0.1-1
- Update to 3.9.0.1

* Thu Jul 10 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.9.0-0.1_rc2
- Update to 3.9.0 rc2
- Switch to wxGTK3 (use wx-config-3.0)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Mon Jun 02 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.8.1-1
- Update to 3.8.1

* Tue Apr 01 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.8.0-1
- Update to 3.8.0

* Wed Feb 12 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.7.4.1-1
- Update to 3.7.4.1

* Wed Feb 12 2014 Nicolas Chauvet <kwizart@gmail.com> - 3.7.4-1
- Update to 3.7.4

* Mon Aug 12 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.3-1
- Update to 3.7.3 - Security fixes
 CVE-2013-4206, CVE-2013-4207, CVE-2013-4208, CVE-2013-4852

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.7.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 21 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.1-1
- Update to 3.7.1

* Mon May 27 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.0.2-1
- Update to 3.7.0.2

* Mon May 13 2013 Nicolas Chauvet <kwizart@gmail.com> - 3.7.0.1-1
- Update to 3.7.0.1
